@@ -1,9 +1,9 @@
 /***************************************************************************
     File                 : OriginFile.h
     --------------------------------------------------------------------
-    Copyright            : (C) 2005-2007 Stefan Gerlach
-                           (C) 2007-2008 Alex Kargovsky, Ion Vasilief
-    Email (use @ for *)  : kargovsky*yumr.phys.msu.su, ion_vasilief*yahoo.fr
+	Copyright            : (C) 2007-2008 Alex Kargovsky
+						   (C) 2008-2011 Ion Vasilief
+	Email (use @ for *)  : ion_vasilief*yahoo.fr
     Description          : Origin file import class
 
  ***************************************************************************/
@@ -30,9 +30,9 @@
 #ifndef ORIGIN_FILE_H
 #define ORIGIN_FILE_H
 
-/* version 0.0 2007-09-26 */
-#define LIBORIGIN_VERSION 0x00070926
-#define LIBORIGIN_VERSION_STRING "2007-09-26"
+/* version 0.0 2011-01-17 */
+#define LIBORIGIN_VERSION 0x00110117
+#define LIBORIGIN_VERSION_STRING "2011-01-17"
 
 #include "OriginObj.h"
 #include "OriginParser.h"
